@@ -1,4 +1,4 @@
-/* Copyright (c) 2006-2010 Jonas Fonseca <fonseca@diku.dk>
+/* Copyright (c) 2006-2013 Jonas Fonseca <fonseca@diku.dk>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -9,18 +9,20 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- *
- * Example usage:
- *
- *	# git log --pretty=raw --parents | ./test-graph
- *	# git log --pretty=raw --parents | ./test-graph --ascii
  */
 
 #include "tig.h"
 #include "io.h"
 #include "graph.h"
 
-static void __NORETURN
+#define USAGE \
+"test-graph [--ascii]\n" \
+"\n" \
+"Example usage:\n" \
+"	# git log --pretty=raw --parents | ./test-graph\n" \
+"	# git log --pretty=raw --parents | ./test-graph --ascii"
+
+static void TIG_NORETURN
 die(const char *err, ...)
 {
 	va_list args;
@@ -28,7 +30,7 @@ die(const char *err, ...)
 	endwin();
 
 	va_start(args, err);
-	fputs("tig: ", stderr);
+	fputs("test-graph: ", stderr);
 	vfprintf(stderr, err, args);
 	fputs("\n", stderr);
 	va_end(args);
@@ -58,6 +60,10 @@ main(int argc, const char *argv[])
 	if (argc > 1 && !strcmp(argv[1], "--ascii"))
 		graph_fn = graph_symbol_to_ascii;
 
+	if (isatty(STDIN_FILENO)) {
+		die(USAGE);
+	}
+
 	if (!io_open(&io, "%s", ""))
 		die("IO");
 
@@ -104,3 +110,5 @@ main(int argc, const char *argv[])
 
 	return 0;
 }
+
+/* vim: set ts=8 sw=8 noexpandtab: */
